California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 84 - WATER QUALITY, SAFETY AND SUPPLY. FLOOD CONTROL. NATURAL RESOURCE PROTECTION. PARK IMPROVEMENTS. BONDS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1289848 | COMMITTEE FOR CALIFORNIA'S FUTURE, YES ON PROPS 1A, 1B, 1C, 1D, 1E, 84 AND NO ON 85 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287093 | CALIFORNIANS FOR CLEAN WATER, PARKS AND COASTAL PROTECTION / YES ON 84, A COALITION OF CONSERVATION GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1281871 | COMMITTEE FOR CLEAN WATER AND COASTAL PROTECTION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288513 | CALIFORNIA LEAGUE OF CONSERVATION VOTERS 2006 BALLOT MEASURE FUND: NO ON 90, YES ON 84 AND 87 | SUPPORT